The Something Awful Forums

Unregistered User
New around here? Register your SA Forums Account here!
You can: log in, read the tech support FAQ, or request your lost password. This dumb message (and those ads) will appear on every screen until you register! Get rid of this crap by registering your own SA Forums Account and joining roughly 150,000 Goons, for the one-time price of $9.95! We charge money because it costs us money per month for bills, and since we don't believe in showing ads to our users, we try to make the money back through forum registrations.

## Special Message From El Jefe

Sorry, you must be a registered forums member to view this page. If you are already a member, login here.
To register your very own account, see our registration page
A BRIEF OVERVIEW (WHY DO WE CHARGE TO REGISTER?)
In order to offset server costs and bandwidth bills, Something Awful charges a one time only $9.95 fee for a basic forum account registration. As we all know, the Internet industry is pretty much a craphole these days, and the only way website owners can break even is by charging subscriptions. I want to keep the main site and content free of charge, so your registrations and donations help keep both the forums and main server alive, as well as keeping me out of prison for murdering advertising executives.
Some of you may have a problem with the notion of this website charging people for an account. You may say that other forums are free and don't cost anything to register, so there's absolutely no reason for you to pay money for an account here. That is fine by me; if you don't want to pay, I will not ask you to pay. It is a decision completely up to you. The SA forums, however, are a thriving community full of what I feel to be the funniest crowd on the Internet, moderated by some of the best mods to ever squirt out of somebody's womb. We're troll-free and provide the best viewer-created content out of any website. If you feel you would like to join us, I freely invite you to do so. If you would not like to join or take offense to paying money for a forum account, I freely invite you to not do so. The choice is up to you.
HOW TO REGISTER AN ACCOUNT:
By registering an account, the user agrees to abide by all the forum rules and regulations. If the user breaks any forum rule (as determined by a Something Awful Forums moderator or admin), their account could be banned and will need to register a new account. User must read the forum rules before registering, as the act of registration represents the user's agreement to all stated rules and regulations and signifies the user's intent to abide by these rules.

CLICK HERE TO REGISTER YOUR ACCOUNT

If you have any other questions or comments, feel free to contact us. Thank you for your support and helping keep this website alive.
Powered by: vBulletin Version 2.2.9 (SABB-v2.24.12)
Copyright ©2000, 2001, Jelsoft Enterprises Limited.
Copyright ©2024, Jeffrey of YOSPOS
Privacy Policy